@@ -6,11 +6,12 @@ after removing the cwd from sys.path.
 
 import sys
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     # Remove the CWD from sys.path while we load stuff.
     # This is added back by InteractiveShellApp.init_path()
-    if sys.path[0] == '':
+    if sys.path[0] == "":
         del sys.path[0]
 
     from ipykernel import kernelapp as app
+
     app.launch_new_instance()
